@@ -13,8 +13,8 @@ use warnings;
 use Lingua::ZH::CEDICT;
 
 my $dict = Lingua::ZH::CEDICT->new(source        => 'Textfile',
-                                   filename      => './data/cedict.b5.utf8',
-                                   targetCharset => '');
+                                   filename      => './data/cedict.b5.utf-8',
+				   targetCharset => "");
 
 print "Reading CEDICT...\n";
 $dict->init();
@@ -28,4 +28,4 @@ my $store = Lingua::ZH::CEDICT->new(source   => 'Storable',
 
 $store->importData($dict);
 
-# eof ***********************************************************************
\ No newline at end of file
+# eof ***********************************************************************
